@@ -113,7 +113,7 @@ Example:
 """
 import os
 from os.path import join, normpath, basename, exists
-import warnings
+# import warnings
 
 
 class Cacher(object):
@@ -293,9 +293,11 @@ class Cacher(object):
             cfgstr = self.cfgstr
 
         if cfgstr is None and self.enabled:
-            warnings.warn(
-                'No depends given in Cacher constructor or call for {}'.format(
-                    self.fname), UserWarning)
+            # This likely does not need to warn anymore. It is ok if no
+            # dependencies are specified. That is an expected use case.
+            # warnings.warn(
+            #     'No depends given in Cacher constructor or call for {}'.format(
+            #         self.fname), UserWarning)
             cfgstr = ''
         if self.fname is None:
             raise AssertionError('no fname specified in Cacher')
@@ -339,7 +341,8 @@ class Cacher(object):
             >>> # xdoctest: +REQUIRES(module:pytest)
             >>> from ubelt.util_cache import Cacher
             >>> import pytest
-            >>> with pytest.warns(UserWarning):
+            >>> #with pytest.warns(UserWarning):
+            >>> if 1:  # we no longer warn here
             >>>     cacher = Cacher('test_cacher1')
             >>>     cacher.get_fpath()
             >>> self = Cacher('test_cacher2', depends='cfg1')
@@ -774,6 +777,10 @@ class CacheStamp(object):
         cfgstr (str | None):
             DEPRECATED in favor or depends.
 
+    Notes:
+        The size, mtime, and hash mechanism is similar to how Makefile and redo
+        caches work.
+
     Example:
         >>> import ubelt as ub
         >>> # Stamp the computation of expensive-to-compute.txt
@@ -1000,7 +1007,7 @@ class CacheStamp(object):
                 print('[cacher] stamp expired {}'.format(err))
             return err
 
-        expires = certificate['expires']
+        expires = certificate.get('expires', None)
         if expires is not None:
             from ubelt import util_time
             # Need to add in the local timezone to compare against the cert.
