@@ -39,24 +39,31 @@ def _needs_workaround39103():
     return len(datetime_cls(1, 1, 1).strftime('%Y')) != 4
 
 
-def timestamp(datetime=None, precision=0, method='iso8601'):
+def timestamp(datetime=None, precision=0, default_timezone='local',
+              allow_dateutil=True):
     """
     Make a concise iso8601 timestamp suitable for use in filenames.
 
     Args:
-        datetime (datetime.datetime | None):
+        datetime (datetime.datetime | datetime.date | None):
             A datetime to format into a timestamp. If unspecified, the current
-            local time is used.
-
-        method (str):
-            Type of timestamp. Currently the only option is iso8601.
-            This argument may be removed in the future.
+            local time is used. If given as a date, the time 00:00 is used.
 
         precision (int):
             if non-zero, adds up to 6 digits of sub-second precision.
 
+        default_timezone (str | datetime.timezone):
+            if the input does not specify a timezone, assume this one.
+            Can be "local" or "utc", or a standardized code if dateutil is
+            installed.
+
+        allow_dateutil (bool):
+            if True, will use dateutil to lookup the default timezone if needed
+
     Returns:
-        str: stamp
+        str:
+            The timestamp, which will always contain a date, time, and
+            timezone.
 
     Note:
         For more info see [WikiISO8601]_, [PyStrptime]_, [PyTime]_.
@@ -66,9 +73,6 @@ def timestamp(datetime=None, precision=0, method='iso8601'):
         .. [PyStrptime] https://docs.python.org/3/library/datetime.html#strftime-strptime-behavior
         .. [PyTime] https://docs.python.org/3/library/time.html
 
-    TODO:
-        - [ ] Allow defaulting to local or utm timezone (currently default is local)
-
     Example:
         >>> import ubelt as ub
         >>> stamp = ub.timestamp()
@@ -93,6 +97,22 @@ def timestamp(datetime=None, precision=0, method='iso8601'):
         >>> print('stamp = {!r}'.format(stamp))
         stamp = '1973-11-29T213309.12+0930'
 
+        >>> # Can accept datetime or date objects with local, utc, or custom default timezones
+        >>> act_tzinfo = datetime_mod.timezone(datetime_mod.timedelta(hours=+9.5), 'ACT')
+        >>> datetime_utc = ub.timeparse('2020-03-05T112233', default_timezone='utc')
+        >>> datetime_act = ub.timeparse('2020-03-05T112233', default_timezone=act_tzinfo)
+        >>> datetime_notz = datetime_utc.replace(tzinfo=None)
+        >>> date = datetime_utc.date()
+        >>> stamp_utc = ub.timestamp(datetime_utc)
+        >>> stamp_act = ub.timestamp(datetime_act)
+        >>> stamp_date_utc = ub.timestamp(date, default_timezone='utc')
+        >>> print(f'stamp_utc      = {stamp_utc}')
+        >>> print(f'stamp_act      = {stamp_act}')
+        >>> print(f'stamp_date_utc = {stamp_date_utc}')
+        stamp_utc      = 2020-03-05T112233+0
+        stamp_act      = 2020-03-05T112233+0930
+        stamp_date_utc = 2020-03-05T000000+0
+
     Example:
         >>> # xdoctest: +REQUIRES(module:dateutil)
         >>> # Make sure we are compatible with dateutil
@@ -100,8 +120,9 @@ def timestamp(datetime=None, precision=0, method='iso8601'):
         >>> from dateutil.tz import tzlocal
         >>> import datetime as datetime_mod
         >>> from datetime import datetime as datetime_cls
+        >>> tz_act = datetime_mod.timezone(datetime_mod.timedelta(hours=+9.5), 'ACT')
         >>> tzinfo_list = [
-        >>>     datetime_mod.timezone(datetime_mod.timedelta(hours=+9.5), 'ACT'),
+        >>>     tz_act,
         >>>     datetime_mod.timezone(datetime_mod.timedelta(hours=-4), 'AST'),
         >>>     datetime_mod.timezone(datetime_mod.timedelta(hours=0), 'UTC'),
         >>>     datetime_mod.timezone.utc,
@@ -119,6 +140,7 @@ def timestamp(datetime=None, precision=0, method='iso8601'):
         >>>     'precision': [0, 3, 9],
         >>>     'tzinfo': tzinfo_list,
         >>>     'datetime': datetime_list,
+        >>>     'default_timezone': ['local', 'utc', tz_act],
         >>> }
         >>> for params in ub.named_product(basis):
         >>>     dtime = params['datetime'].replace(tzinfo=params['tzinfo'])
@@ -137,48 +159,61 @@ def timestamp(datetime=None, precision=0, method='iso8601'):
         >>>     b = int(recon.timestamp() * shift)
         >>>     assert a == b, f'{a} != {b}'
     """
-    if method == 'iso8601':
-        from datetime import datetime as datetime_cls
-        if datetime is None:
-            datetime = datetime_cls.now()
+    import datetime as datetime_mod
+    from datetime import datetime as datetime_cls
 
-        if datetime.tzinfo is None:
-            # Assume the local timezone (time.timezone is negated)
-            offset_seconds = -time.timezone
-        else:
-            offset_seconds = datetime.tzinfo.utcoffset(datetime).total_seconds()
+    datetime_obj = datetime
+    offset_seconds = None
 
-        seconds_per_hour = 3600
-        tz_hour, tz_remain = divmod(offset_seconds, seconds_per_hour)
-        tz_hour = int(tz_hour)
-        if tz_remain:
-            seconds_per_minute = 60
-            tz_min = int(tz_remain // seconds_per_minute)
-            utc_offset = '{:+03d}{:02d}'.format(tz_hour, tz_min)
-        else:
-            utc_offset = str(tz_hour) if tz_hour < 0 else '+' + str(tz_hour)
-        if precision > 0:
-            fprecision = 6  # microseconds are padded to 6 decimals
-            # NOTE: The time.strftime and datetime.datetime.strftime methods
-            # seem to work differently. The former does not support %f
-            if _needs_workaround39103():  # nocover
-                local_stamp = datetime.strftime('%04Y-%m-%dT%H%M%S.%f')
-            else:  # nocover
-                local_stamp = datetime.strftime('%Y-%m-%dT%H%M%S.%f')
-            ms_offset = len(local_stamp) - max(0, fprecision - precision)
-            local_stamp = local_stamp[:ms_offset]
-        else:
-            if _needs_workaround39103():  # nocover
-                local_stamp = datetime.strftime('%04Y-%m-%dT%H%M%S')
-            else:  # nocover
-                local_stamp = datetime.strftime('%Y-%m-%dT%H%M%S')
-        stamp = local_stamp + utc_offset
-        return stamp
+    # datetime inherits from date. Strange, so we cant use this. See:
+    # https://github.com/python/typeshed/issues/4802
+    if isinstance(datetime_obj, datetime_mod.date) and not isinstance(datetime_obj, datetime_cls):
+        # Coerce a date to datetime.datetime
+        datetime_obj = datetime_cls.combine(datetime_obj, datetime_cls.min.time())
+
+    if datetime_obj is None or datetime_obj.tzinfo is None:
+        # In either case, we need to construct a timezone object
+        tzinfo = _timezone_coerce(default_timezone,
+                                  allow_dateutil=allow_dateutil)
+        # If datetime_obj is unspecified, create a timezone aware now object
+        if datetime_obj is None:
+            datetime_obj = datetime_cls.now(tzinfo)
     else:
-        raise ValueError('only iso8601 is allowed for method')
+        tzinfo = datetime_obj.tzinfo
+
+    # the arg to utcoffset is confusing
+    offset_seconds = tzinfo.utcoffset(datetime_obj).total_seconds()
+    # offset_seconds = tzinfo.utcoffset(None).total_seconds()
+
+    seconds_per_hour = 3600
+    tz_hour, tz_remain = divmod(offset_seconds, seconds_per_hour)
+    tz_hour = int(tz_hour)
+    if tz_remain:
+        seconds_per_minute = 60
+        tz_min = int(tz_remain // seconds_per_minute)
+        utc_offset = '{:+03d}{:02d}'.format(tz_hour, tz_min)
+    else:
+        utc_offset = str(tz_hour) if tz_hour < 0 else '+' + str(tz_hour)
+    if precision > 0:
+        fprecision = 6  # microseconds are padded to 6 decimals
+        # NOTE: The time.strftime and datetime.datetime.strftime methods
+        # seem to work differently. The former does not support %f
+        if _needs_workaround39103():  # nocover
+            local_stamp = datetime_obj.strftime('%04Y-%m-%dT%H%M%S.%f')
+        else:  # nocover
+            local_stamp = datetime_obj.strftime('%Y-%m-%dT%H%M%S.%f')
+        ms_offset = len(local_stamp) - max(0, fprecision - precision)
+        local_stamp = local_stamp[:ms_offset]
+    else:
+        if _needs_workaround39103():  # nocover
+            local_stamp = datetime_obj.strftime('%04Y-%m-%dT%H%M%S')
+        else:  # nocover
+            local_stamp = datetime_obj.strftime('%Y-%m-%dT%H%M%S')
+    stamp = local_stamp + utc_offset
+    return stamp
 
 
-def timeparse(stamp, allow_dateutil=True):
+def timeparse(stamp, default_timezone='local', allow_dateutil=True):
     """
     Create a :class:`datetime.datetime` object from a string timestamp.
 
@@ -191,6 +226,10 @@ def timeparse(stamp, allow_dateutil=True):
         stamp (str):
             a string encoded timestamp
 
+        default_timezone (str):
+            if the input does not specify a timezone, assume this one.
+            Can be "local" or "utc".
+
         allow_dateutil (bool):
             if False we only use the minimal parsing and do not allow a
             fallback to dateutil.
@@ -219,6 +258,7 @@ def timeparse(stamp, allow_dateutil=True):
         >>> import ubelt as ub
         >>> # We should always be able to parse these
         >>> good_stamps = [
+        >>>     '2000-11-22',
         >>>     '2000-11-22T111111.44444Z',
         >>>     '2000-11-22T111111.44444+5',
         >>>     '2000-11-22T111111.44444-05',
@@ -263,9 +303,8 @@ def timeparse(stamp, allow_dateutil=True):
         ti.reset('standard ubelt.timeparse').call(lambda: ub.timeparse('2000-01-02T112358.12345+0500'))
         ti.reset('standard datetime_cls.strptime').call(lambda: datetime_cls.strptime('2000-01-02T112358.12345+0500', '%Y-%m-%dT%H%M%S.%f%z'))
     """
-    import datetime as datetime_mod
     from datetime import datetime as datetime_cls
-    datetime = None
+    datetime_obj = None
     # Check if we might have a minimal format
     maybe_minimal = (
         len(stamp) >= 17 and 'T' in stamp[10:]
@@ -298,22 +337,29 @@ def timeparse(stamp, allow_dateutil=True):
                 tz_part = '{}00'.format(tz_part)
             fixed_stamp = ''.join([date_part, 'T', time_part, sign, tz_part])
 
-    if maybe_minimal:
+    if len(stamp) == 10:
+        try:
+            fmt =  '%Y-%m-%d'
+            datetime_obj = datetime_cls.strptime(fixed_stamp, fmt)
+        except ValueError:
+            pass
+
+    if maybe_minimal and datetime_obj is None:
         minimal_formats = [
             '%Y-%m-%dT%H%M%S%z',
-            '%Y-%m-%dT%H%M%S.%f%z',
             '%Y-%m-%dT%H%M%S',
+            '%Y-%m-%dT%H%M%S.%f%z',
             '%Y-%m-%dT%H%M%S.%f',
         ]
         for fmt in minimal_formats:
             try:
-                datetime = datetime_cls.strptime(fixed_stamp, fmt)
+                datetime_obj = datetime_cls.strptime(fixed_stamp, fmt)
             except ValueError:
                 pass
             else:
                 break
 
-    if datetime is None:
+    if datetime_obj is None:
         # Our minimal logic did not work, can we use dateutil?
         if not allow_dateutil:
             raise ValueError((
@@ -329,13 +375,98 @@ def timeparse(stamp, allow_dateutil=True):
                     'Unknown string format: {!r}, and '
                     'dateutil is not installed').format(stamp)) from None
             else:  # nocover
-                datetime = du_parse(stamp)
+                datetime_obj = du_parse(stamp)
 
-    if datetime.tzinfo is None:
-        # If the timezone is unspecified assume the local timezone
-        tzinfo = datetime_mod.timezone(datetime_mod.timedelta(seconds=-time.timezone))
-        datetime = datetime.replace(tzinfo=tzinfo)
-    return datetime
+    if datetime_obj.tzinfo is None:
+        # Timezone is unspecified, need to construct the default one.
+        tzinfo = _timezone_coerce(default_timezone,
+                                  allow_dateutil=allow_dateutil)
+        datetime_obj = datetime_obj.replace(tzinfo=tzinfo)
+
+    return datetime_obj
+
+
+def _timezone_coerce(tzinfo, allow_dateutil=True):
+    """
+    Ensure output it a timezone instance.
+
+    Example:
+        >>> import pytest
+        >>> from ubelt.util_time import *  # NOQA
+        >>> from ubelt.util_time import _timezone_coerce
+        >>> results = []
+        >>> write = results.append
+        >>> tzinfo = _timezone_coerce('utc', allow_dateutil=0)
+        >>> print(f'tzinfo={tzinfo}')
+        tzinfo=UTC
+
+    Example:
+        >>> # xdoctest: +REQUIRES(module:dateutil)
+        >>> import pytest
+        >>> results = []
+        >>> write = results.append
+        >>> write(_timezone_coerce('utc'))
+        >>> write(_timezone_coerce('GMT'))
+        >>> write(_timezone_coerce('EST'))
+        >>> write(_timezone_coerce('HST'))
+        >>> import datetime as datetime_mod
+        >>> dt = datetime_mod.datetime.now()
+        >>> for tzinfo in results:
+        >>>     print(f'tzoffset={tzinfo.utcoffset(dt).total_seconds()}')
+        tzoffset=0.0
+        tzoffset=0.0
+        tzoffset=-18000.0
+        tzoffset=-36000.0
+
+    Example:
+        >>> import pytest
+        >>> from ubelt.util_time import *  # NOQA
+        >>> from ubelt.util_time import _timezone_coerce
+        >>> with pytest.raises(ValueError):
+        ...     _timezone_coerce('GMT', allow_dateutil=0)
+        >>> with pytest.raises(TypeError):
+        ...     _timezone_coerce(object(), allow_dateutil=0)
+        >>> # xdoctest: +REQUIRES(module:dateutil)
+        >>> with pytest.raises(KeyError):
+        ...     _timezone_coerce('NotATimezone', allow_dateutil=1)
+
+    Example:
+        >>> import pytest
+        >>> from ubelt.util_time import *  # NOQA
+        >>> from ubelt.util_time import _timezone_coerce
+        >>> import time
+        >>> tz1 = _timezone_coerce('local', allow_dateutil=0)
+        >>> tz2 = _timezone_coerce('local', allow_dateutil=1)
+        >>> sec1 = tz1.utcoffset(None).total_seconds()
+        >>> sec2 = tz2.utcoffset(None).total_seconds()
+        >>> assert sec1 == sec2 == -time.timezone
+    """
+    import datetime as datetime_mod
+    if isinstance(tzinfo, str):
+        if tzinfo == 'local':
+            # Note: the local timezone time.timezone is negated
+            _delta = datetime_mod.timedelta(seconds=-time.timezone)
+            out_tzinfo = datetime_mod.timezone(_delta)
+        elif tzinfo == 'utc':
+            out_tzinfo = datetime_mod.timezone.utc
+        else:
+            if allow_dateutil:
+                from dateutil import tz as tz_mod
+                out_tzinfo = tz_mod.gettz(tzinfo)
+                if out_tzinfo is None:
+                    raise KeyError(tzinfo)
+            else:
+                raise ValueError((
+                    'Unrecognized timezone: {!r}, and '
+                    'dateutil is not allowed').format(tzinfo))
+    elif isinstance(tzinfo, datetime_mod.timezone):
+        out_tzinfo = tzinfo
+    else:
+        raise TypeError(
+            'Unknown type: {!r} for tzinfo'.format(
+                type(tzinfo))
+        )
+    return out_tzinfo
 
 
 class Timer(object):
